%if 0%{?fedora} >= 33
%bcond_with check
%else
%bcond_without check
%endif

%global srcname txredisapi
%global desc \
txredisapi is a non-blocking client driver for the Redis database, \
written in Python. It uses Twisted for the asynchronous communication \
with Redis. \
\
It started as a fork of the original Redis protocol for Twisted, and \
evolved into a more robust, reliable, and complete solution for \
applications like web servers. These types of applications often need a \
fault-tolerant pool of connections with multiple Redis servers, making it \
possible to easily develop and maintain distributed systems. \
\
Most of the Redis commands are supported, as well as other features such as \
silent reconnection, connection pools, and automatic sharding. \
\
This driver is distributed as part of the cyclone web framework.


Name:           python-%{srcname}
Version:        1.4.7
Release:        2%{?dist}.2
Summary:        Non-blocking Redis client for Python

License:        ASL 2.0
URL:            https://github.com/IlyaSkriblovsky/txredisapi
Source0:        https://github.com/IlyaSkriblovsky/txredisapi/archive/%{version}/txredisapi-%{version}.tar.gz
Patch0:         python-txredisapi-redisport.patch
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%if %{with check}
BuildRequires:  python3-twisted
BuildRequires:  python3-mock
BuildRequires:  redis
%endif

%description %{desc}

%package -n     python3-%{srcname}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{srcname}}
Requires:       python3-six
Requires:       python3-twisted
%description -n python3-%{srcname} %{desc}


%prep
%autosetup -n %{srcname}-%{version} -p1
# Remove bundled egg-info
rm -rf %{srcname}.egg-info

%build
%py3_build


%install
%py3_install


%check
%if %{with check}
export REDIS_PORT=16379
%{_bindir}/redis-server --port $REDIS_PORT &
redis_pid=$!
trap "kill $redis_pid" EXIT
%{__python3} -m unittest discover -v
kill "$redis_pid"
trap '' EXIT
%endif


%files -n python3-%{srcname}
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/%{srcname}.py
%{python3_sitelib}/%{srcname}-%{version}-py%{python3_version}.egg-info


%changelog
* Fri Oct 30 2020 Oleg Girko <ol@infoserver.lv> - 1.4.7-2
- Make unit tests conditional and disable on Fedora >= 33
* Tue Oct 27 2020 Oleg Girko <ol@infoserver.lv> - 1.4.7-1
- Update to 1.4.7
- Update URL
- Enable unit tests
* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild
* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.4.4-11
- Rebuilt for Python 3.9
* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild
* Thu Oct  3 2019 Miro Hrončok <mhroncok@redhat.com> - 1.4.4-9
- Rebuilt for Python 3.8.0rc1 (#1748018)
* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 1.4.4-8
- Rebuilt for Python 3.8
* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild
* Sat Feb  2 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild
* Fri Oct 12 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.4.4-5
- Python2 binary package has been removed
  See https://fedoraproject.org/wiki/Changes/Mass_Python_2_Package_Removal
* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild
* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.4.4-3
- Rebuilt for Python 3.7
* Fri Feb  9 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild
* Wed Jan 31 2018 Aurelien Bompard <abompard@fedoraproject.org> - 1.4.4-1
- Initial package.
